==> qsr-2.6.5.tar.gz: qsr-2.6.5/README.md <==

## Simple Quick Screen Record
<p>
<a href="https://github.com/rstusoftdev/QSR/releases"><img src="https://img.shields.io/badge/2.9.12-HexColor?style=flat-square&label=Latest&color=blue"/></a>
<a href="https://github.com/rstusoftdev/QSR/blob/main/LICENSE"><img src="https://img.shields.io/badge/GPL v3-HexColor?style=flat-square&label=License&color=blue"/></a>
<a href="https://www.python.org/"><img src="https://img.shields.io/badge/Python-3776AB?style=flat-square&logo=python&logoColor=white" /></a>
<a href="https://docs.microsoft.com/en-us/dotnet/csharp/"><img src="https://img.shields.io/badge/C%23-239120?style=flat-square&logo=c-sharp&logoColor=white" /></a>
<a href="https://dotnet.microsoft.com/download/dotnet-framework"><img src="https://img.shields.io/badge/.NET-512BD4?style=flat-square&logo=dotnet&logoColor=white" /></a>
</p>
Quick Screen Record is The software that can help you record screen quickly.
  
---


## Install Package
just type ```pip install qsr``` on your terminal

## Requirement
 
 - Operating system
    <br> <p>
   <img src="https://img.shields.io/badge/Windows 8-0078D6?style=for-the-badge&logo=windows&logoColor=white"/>
   <img src="https://img.shields.io/badge/Windows 8.1-0078D6?style=for-the-badge&logo=windows&logoColor=white"/>
   <img src="https://img.shields.io/badge/Windows 10-0078D6?style=for-the-badge&logo=windows&logoColor=white"/> x64 bit</p>


 - Processor <br><p>
   <img src="https://img.shields.io/badge/Intel-DualCore-0071C5?style=for-the-badge&logo=intel&logoColor=white"/>
    </p>
    
 - Display <br>
   1280 x 960 - 1920 x 1080 
    
 - Other <br>
   <a href="https://www.python.org/"><img src="https://img.shields.io/badge/Python 3.9-3776AB?style=for-the-badge&logo=python&logoColor=white" /></a>
   </p>
   
## Support
  
Follow Us On
<p>  
<a href="https://discord.io/RStuTeamServer"><img src="https://img.shields.io/badge/Discord-7289DA?style=for-the-badge&logo=discord&logoColor=white"/></a>
<a href="https://twitter.com/radit_rstuanim"><img src="https://img.shields.io/badge/Twitter-1DA1F2?style=for-the-badge&logo=twitter&logoColor=white"/></a>
<a href="https://dribbble.com/R_Stu_Team"><img src="https://img.shields.io/badge/Dribbble-EA4C89?style=for-the-badge&logo=dribbble&logoColor=white"/></a>
<a href="https://github.com/rstusoftdev"><img src="https://img.shields.io/badge/GitHub-100000?style=for-the-badge&logo=github&logoColor=white"/></a>
<a href="https://www.youtube.com/channel/UCFKHdP2BYzlEslkv4UPv-CQ"><img src="https://img.shields.io/badge/YouTube-FF0000?style=for-the-badge&logo=youtube&logoColor=white"/></a>
<a href="https://www.artstation.com/rstuanim"><img src="https://img.shields.io/badge/ArtStation-13AFF0?style=for-the-badge&logo=ArtStation&logoColor=white"/></a>
</p>
<br>
  <br>
  


<img src="https://github.com/rstusoftdev/badge/blob/main/R%20STu%20Banner.svg" alt="banner" />

©2021  R Stu Team │ All Right Reserved.

==> qsr-2.6.6.tar.gz: qsr-2.6.6/README.md <==

## Simple Quick Screen Record
<p>
<a href="https://github.com/rstusoftdev/QSR/releases"><img src="https://img.shields.io/badge/2.9.12-HexColor?style=flat-square&label=Latest&color=blue"/></a>
<a href="https://github.com/rstusoftdev/QSR/blob/main/LICENSE"><img src="https://img.shields.io/badge/GPL v3-HexColor?style=flat-square&label=License&color=blue"/></a>
<a href="https://www.python.org/"><img src="https://img.shields.io/badge/Python-3776AB?style=flat-square&logo=python&logoColor=white" /></a>
<a href="https://docs.microsoft.com/en-us/dotnet/csharp/"><img src="https://img.shields.io/badge/C%23-239120?style=flat-square&logo=c-sharp&logoColor=white" /></a>
<a href="https://dotnet.microsoft.com/download/dotnet-framework"><img src="https://img.shields.io/badge/.NET-512BD4?style=flat-square&logo=dotnet&logoColor=white" /></a>
</p>
Quick Screen Record is The software that can help you record screen quickly.
  
---


## Usage
 - first, install qsr, just type ```pip install qsr``` on your terminal
 - second, type ```C:\Users\USER\AppData\Local\Programs\Python\Python39\Lib\site-packages\qsr\qsr.py``` on your terminal to run the software
 - last, just follow what the command say, and yeah, now you can use it

## Requirement
 
 - Operating system
    <br> <p>
   <img src="https://img.shields.io/badge/Windows 8-0078D6?style=for-the-badge&logo=windows&logoColor=white"/>
   <img src="https://img.shields.io/badge/Windows 8.1-0078D6?style=for-the-badge&logo=windows&logoColor=white"/>
   <img src="https://img.shields.io/badge/Windows 10-0078D6?style=for-the-badge&logo=windows&logoColor=white"/> x64 bit</p>


 - Processor <br><p>
   <img src="https://img.shields.io/badge/Intel-DualCore-0071C5?style=for-the-badge&logo=intel&logoColor=white"/>
    </p>
    
 - Display <br>
   1280 x 960 - 1920 x 1080 
    
 - Other <br>
   <a href="https://www.python.org/"><img src="https://img.shields.io/badge/Python 3.9-3776AB?style=for-the-badge&logo=python&logoColor=white" /></a>
   </p>
   
## Support
  
Follow Us On
<p>  
<a href="https://discord.io/RStuTeamServer"><img src="https://img.shields.io/badge/Discord-7289DA?style=for-the-badge&logo=discord&logoColor=white"/></a>
<a href="https://twitter.com/radit_rstuanim"><img src="https://img.shields.io/badge/Twitter-1DA1F2?style=for-the-badge&logo=twitter&logoColor=white"/></a>
<a href="https://dribbble.com/R_Stu_Team"><img src="https://img.shields.io/badge/Dribbble-EA4C89?style=for-the-badge&logo=dribbble&logoColor=white"/></a>
<a href="https://github.com/rstusoftdev"><img src="https://img.shields.io/badge/GitHub-100000?style=for-the-badge&logo=github&logoColor=white"/></a>
<a href="https://www.youtube.com/channel/UCFKHdP2BYzlEslkv4UPv-CQ"><img src="https://img.shields.io/badge/YouTube-FF0000?style=for-the-badge&logo=youtube&logoColor=white"/></a>
<a href="https://www.artstation.com/rstuanim"><img src="https://img.shields.io/badge/ArtStation-13AFF0?style=for-the-badge&logo=ArtStation&logoColor=white"/></a>
</p>
<br>
  <br>
  


<img src="https://github.com/rstusoftdev/badge/blob/main/R%20STu%20Banner.svg" alt="banner" />

©2021  R Stu Team │ All Right Reserved.
